@@ -1,3 +1,5 @@
+from .attachment import Attachment
+from .tools import to_datetime
 
 
 class Note(object):
@@ -21,7 +23,9 @@ class Note(object):
         self.attachments = []
 
     def save_data(self, note):
-        self.highrise_id = note['id']
+        self.highrise_id = note['id'].pyval
+        self.created_at = to_datetime(note['created-at'].pyval)
+        self.updated_at = to_datetime(note['updated-at'].pyval)
 
         for attr in [
             'body',
@@ -34,10 +38,8 @@ class Note(object):
             'visible-to',
             'owner-id',
             'group-id',
-            'updated-at',
-            'created-at',
         ]:
-            setattr(self, attr.replace('-', '_',), note[attr])
+            setattr(self, attr.replace('-', '_',), note[attr].pyval)
 
         if hasattr(note, 'attachments'):
             self.set_attachments(note['attachments'])
@@ -46,18 +48,4 @@ class Note(object):
         for attachment in attachments.getchildren():
             current_attachment = Attachment()
             current_attachment.save_data(attachment)
-            self.attachments.append(current_attachment)
-
-
-class Attachment(object):
-    """
-        highrise_id
-        url
-        name
-        size
-    """
-    def save_data(self, attachment):
-        self.highrise_id = attachment['id']
-
-        for attr in ['url', 'name', 'size']:
-            setattr(self, attr, attachment[attr])
\ No newline at end of file
+            self.attachments.append(current_attachment)
\ No newline at end of file
